<a id="aea.configurations.constants"></a>

# aea.configurations.constants

Module to declare constants.

<a id="aea.configurations.constants.CONFIG_FILE_TO_PACKAGE_TYPE"></a>

#### CONFIG`_`FILE`_`TO`_`PACKAGE`_`TYPE

type: Dict[str, str]

<a id="aea.configurations.constants.PACKAGE_TYPE_TO_CONFIG_FILE"></a>

#### PACKAGE`_`TYPE`_`TO`_`CONFIG`_`FILE

type: Dict[str, str]

